@@ -104,11 +104,6 @@ APPLICATIONS_SCHEMA = {
                 "enum": ["MapR", "HIVE", "PIG", "HBASE", "IMPALA", "GANGLIA"],
                 "required": True
             },
-            "Version": {
-                "type": "string",
-                "description":
-                    "Version number of the application to be installed."
-            },
             "Args": {
                 "type": "array",
                 "description":
@@ -168,11 +163,6 @@ STEPS_SCHEMA = {
                 "type": "string",
                 "description": "The name of the step. ",
             },
-            "Version": {
-                "type": "string",
-                "default": "latest",
-                "description": "The application version. "
-            },
             "ActionOnFailure": {
                 "type": "string",
                 "description": "The action to take if the cluster step fails.",
