@@ -148,23 +148,6 @@ def check_required_field(structure, name, value):
             object_name=structure, missing=name)
 
 
-def build_pig_install_step(region, version,
-                           action_on_failure=constants.TERMINATE_CLUSTER):
-    step_args = [
-        build_s3_link(constants.PIG_SCRIPT_PATH, region),
-        constants.INSTALL_PIG_ARG,
-        constants.BASE_PATH_ARG,
-        build_s3_link(constants.PIG_BASE_PATH, region),
-        constants.PIG_VERSIONS,
-        version]
-    step = build_step(
-        name=constants.INSTALL_PIG_NAME,
-        action_on_failure=action_on_failure,
-        jar=build_s3_link(constants.SCRIPT_RUNNER_PATH, region),
-        args=step_args)
-    return step
-
-
 def call(session, operation_object, parameters, region_name=None,
          endpoint_url=None, verify=None):
         # We could get an error from get_endpoint() about not having
@@ -220,27 +203,30 @@ def get_cluster_state(session, parsed_globals, cluster_id):
     return data['Cluster']['Status']['State']
 
 
-def find_master_instance(session, parsed_globals, cluster_id):
-    """ Find master instance from the list of instances. """
-
+def _find_master_instance(session, parsed_globals, cluster_id):
+    """
+    Find the most recently created master instance.
+    If the master instance is not available yet,
+     the method will return None.
+    """
     emr = session.get_service('emr')
     endpoint = get_endpoint(emr, parsed_globals)
-    cluster_state = get_cluster_state(session, parsed_globals, cluster_id)
-    if any(cluster_state == i for i in constants.TERMINATED_STATES):
-        raise exceptions.ClusterTerminatedError
+    operation_object = emr.get_operation('ListInstances')
+    pages = operation_object.paginate(
+        endpoint, ClusterId=cluster_id, InstanceGroupTypes=['MASTER'])
+    return _find_most_recently_created(pages)
+
+
+def find_master_public_dns(session, parsed_globals, cluster_id):
+    """
+    Returns the master_instance's 'PublicDnsName'.
+    """
+    master_instance = _find_master_instance(
+        session, parsed_globals, cluster_id)
+    if master_instance is None:
+        return ""
     else:
-        try:
-            cluster_running = emr.get_waiter('ClusterRunning')
-            if cluster_state in constants.STARTING_STATES:
-                print("Waiting for the cluster to start.")
-            cluster_running.wait(endpoint, ClusterId=cluster_id)
-        except WaiterError:
-            return None
-        operation_object = emr.get_operation('ListInstances')
-        pages = operation_object.paginate(
-            endpoint, ClusterId=cluster_id, InstanceGroupTypes=['MASTER'])
-        master_instance = _find_most_recently_created(pages)
-        return master_instance
+        return master_instance.get('PublicDnsName')
 
 
 def which(program):
@@ -266,4 +252,4 @@ def display_response(session, operation, result, parsed_globals):
         # Calling a private method. Should be changed after the functionality
         # is moved outside CliOperationCaller.
         cli_operation_caller._display_response(operation, result,
-                                               parsed_globals)
\ No newline at end of file
+                                               parsed_globals)
