@@ -13,12 +13,12 @@
 import logging
 import sys
 import json
-import jmespath
 
 from botocore.utils import set_value_from_jmespath
 
 from awscli.table import MultiTable, Styler, ColorizedStyler
 from awscli import text
+from awscli import compat
 
 
 LOG = logging.getLogger(__name__)
@@ -40,6 +40,16 @@ class Formatter(object):
                     LOG.debug('RequestId: %s', request_id)
                 del response_data['ResponseMetadata']
 
+    def _get_default_stream(self):
+        if getattr(sys.stdout, 'encoding', None) is None:
+            # In python3, sys.stdout.encoding is always set.
+            # In python2, if you redirect to stdout, then
+            # encoding is not None.  In this case we'll default
+            # to utf-8.
+            return compat.get_stdout_text_writer()
+        else:
+            return sys.stdout
+
 
 class FullyBufferedFormatter(Formatter):
     def __call__(self, operation, response, stream=None):
@@ -47,7 +57,7 @@ class FullyBufferedFormatter(Formatter):
             # Retrieve stdout on invocation instead of at import time
             # so that if anything wraps stdout we'll pick up those changes
             # (specifically colorama on windows wraps stdout).
-            stream = sys.stdout
+            stream = self._get_default_stream()
         # I think the interfaces between non-paginated
         # and paginated responses can still be cleaned up.
         if operation.can_paginate and self._args.paginate:
@@ -207,7 +217,7 @@ class TextFormatter(Formatter):
 
     def __call__(self, operation, response, stream=None):
         if stream is None:
-            stream = sys.stdout
+            stream = self._get_default_stream()
         try:
             if operation.can_paginate and self._args.paginate:
                 result_keys = response.result_keys
