@@ -46,6 +46,7 @@ from awscli.customizations.globalargs import register_parse_global_args
 from awscli.customizations.cloudsearch import initialize as cloudsearch_init
 from awscli.customizations.emr.emr import emr_initialize
 from awscli.customizations.cloudsearchdomain import register_cloudsearchdomain
+from awscli.customizations.s3endpoint import register_s3_endpoint
 
 
 def awscli_initialize(event_handlers):
@@ -94,3 +95,4 @@ def awscli_initialize(event_handlers):
     cloudsearch_init(event_handlers)
     emr_initialize(event_handlers)
     register_cloudsearchdomain(event_handlers)
+    register_s3_endpoint(event_handlers)
